@@ -1,5 +1,5 @@
 /* audispd.c --
- * Copyright 2007-08,2013,2016 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2007-08,2013,2016-17 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,6 +36,7 @@
 #include <arpa/inet.h>
 #include <limits.h>
 #include <sys/uio.h>
+#include <getopt.h>
 
 #include "audispd-config.h"
 #include "audispd-pconfig.h"
@@ -53,8 +54,7 @@ static daemon_conf_t daemon_config;
 static conf_llist plugin_conf;
 static int audit_fd;
 static pthread_t inbound_thread;
-static const char *config_file = "/etc/audisp/audispd.conf";
-static const char *plugin_dir =  "/etc/audisp/plugins.d/";
+static char *config_file = NULL;
 
 /* Local function prototypes */
 static void signal_plugins(int sig);
@@ -63,6 +63,24 @@ static int safe_exec(plugin_conf_t *conf);
 static void *inbound_thread_main(void *arg);
 static void process_inbound_event(int fd);
 
+/*
+ * Output a usage message and exit with an error.
+ */
+static void usage(void)
+{
+	fprintf(stderr, "%s",
+		"Usage: audispd [options]\n"
+		"-c,--config_dir <config_dir_path>: Override default "
+			"configuration file path\n");
+	exit(2);
+}
+
+static void release_memory_exit(int code)
+{
+	free(config_file);
+	exit(code);
+}
+
 /*
  * SIGTERM handler
  */
@@ -132,7 +150,7 @@ static void load_plugin_conf(conf_llist *plugin)
 	plist_create(plugin);
 
 	/* read configs */
-	d = opendir(plugin_dir);
+	d = opendir(daemon_config.plugin_dir);
 	if (d) {
 		struct dirent *e;
 
@@ -145,7 +163,7 @@ static void load_plugin_conf(conf_llist *plugin)
 				continue;
 
 			snprintf(fname, sizeof(fname), "%s%s",
-				plugin_dir, e->d_name);
+				daemon_config.plugin_dir, e->d_name);
 
 			clear_pconfig(&config);
 			if (load_pconfig(&config, fname) == 0) {
@@ -267,14 +285,16 @@ static int reconfigure(void)
 				/* If active and no state change, sighup it */
 				if (opconf->p->type == S_ALWAYS && 
 						opconf->p->active == A_YES) {
-					if (opconf->p->inode==tpconf->p->inode)
-						kill(opconf->p->pid, SIGHUP);
-					else {
+					if (opconf->p->inode==tpconf->p->inode){
+						if (opconf->p->pid)
+						  kill(opconf->p->pid, SIGHUP);
+					} else {
 						/* Binary changed, restart */
 						syslog(LOG_INFO,
 					"Restarting %s since binary changed",
 							opconf->p->path);
-						kill(opconf->p->pid, SIGTERM);
+						if (opconf->p->pid)
+						  kill(opconf->p->pid, SIGTERM);
 						usleep(50000); // 50 msecs
 						close(opconf->p->plug_pipe[1]);
 						opconf->p->plug_pipe[1] = -1;
@@ -309,7 +329,8 @@ static int reconfigure(void)
 		syslog(LOG_INFO, "Terminating %s because its now inactive",
 				tpconf->p->path);
 		if (tpconf->p->type == S_ALWAYS) {
-			kill(tpconf->p->pid, SIGTERM);
+			if (tpconf->p->pid)
+				kill(tpconf->p->pid, SIGTERM);
 			close(tpconf->p->plug_pipe[1]);
 		} else
 			stop_builtin(tpconf->p);
@@ -331,10 +352,41 @@ static int reconfigure(void)
 
 int main(int argc, char *argv[])
 {
+	extern char *optarg;
+	extern int optind;
+	static const struct option opts[] = {
+		{"config_dir", required_argument, NULL, 'c'},
+		{NULL, 0, NULL, 0}
+	};
 	lnode *conf;
 	struct sigaction sa;
 	int i;
 
+	while ((i = getopt_long(argc, argv, "i:c:", opts, NULL)) != -1) {
+		switch (i) {
+			case 'c':
+				if (asprintf(&config_file, "%s/audispd.conf",
+						optarg) < 0) {
+mem_out:
+					printf(
+					"Failed allocating memory, exiting\n");
+					release_memory_exit(1);
+				}
+				break;
+			default:
+				usage();
+		}
+	}
+
+	/* check for trailing command line following options */
+	if (optind < argc)
+		usage();
+
+	if (config_file == NULL)
+		config_file = strdup("/etc/audisp/audispd.conf");
+	if (config_file == NULL)
+		goto mem_out;
+
 	set_aumessage_mode(MSG_SYSLOG, DBG_NO);
 
 	/* Clear any procmask set by libev */
@@ -359,15 +411,11 @@ int main(int argc, char *argv[])
 	sigaction(SIGCHLD, &sa, NULL);
 	setsid();
 
-	/* move stdin to its own fd */
-	if (argc == 3 && strcmp(argv[1], "--input") == 0) 
-		audit_fd = open(argv[2], O_RDONLY);
-	else
-		audit_fd = dup(0);
+	audit_fd = dup(0);
 	if (audit_fd < 0) {
 		syslog(LOG_ERR, "Failed setting up input(%s, %d), exiting",
 				strerror(errno), audit_fd);
-		return 1;
+		release_memory_exit(1);
 	}
 
 	/* Make all descriptors point to dev null */
@@ -376,30 +424,35 @@ int main(int argc, char *argv[])
 		if (dup2(0, i) < 0 || dup2(1, i) < 0 || dup2(2, i) < 0) {
 			syslog(LOG_ERR, "Failed duping /dev/null %s, exiting",
 					strerror(errno));
-			return 1;
+			release_memory_exit(1);
 		}
 		close(i);
 	} else {
 		syslog(LOG_ERR, "Failed opening /dev/null %s, exiting",
 					strerror(errno));
-		return 1;
+		close(audit_fd);
+		release_memory_exit(1);
 	}
 	if (fcntl(audit_fd, F_SETFD, FD_CLOEXEC) < 0) {
 		syslog(LOG_ERR, "Failed protecting input %s, exiting",
 					strerror(errno));
-		return 1;
+		close(audit_fd);
+		release_memory_exit(1);
 	}
 
 	/* init the daemon's config */
-	if (load_config(&daemon_config, config_file))
-		return 6;
+	if (load_config(&daemon_config, config_file)) {
+		close(audit_fd);
+		release_memory_exit(6);
+	}
 
 	load_plugin_conf(&plugin_conf);
 
 	/* if no plugins - exit */
 	if (plist_count(&plugin_conf) == 0) {
 		syslog(LOG_NOTICE, "No plugins found, exiting");
-		return 0;
+		close(audit_fd);
+		release_memory_exit(0);
 	}
 
 	/* Plugins are started with the auditd priority */
@@ -427,7 +480,9 @@ int main(int argc, char *argv[])
 	/* Tell it to poll the audit fd */
 	if (add_event(audit_fd, process_inbound_event) < 0) {
 		syslog(LOG_ERR, "Cannot add event, exiting");
-		return 1;
+		close(audit_fd);
+		close(i);
+		release_memory_exit(1);
 	}
 
 	/* Create inbound thread */
@@ -472,6 +527,7 @@ int main(int argc, char *argv[])
 	/* Cleanup the queue */
 	destroy_queue();
 	free_config(&daemon_config);
+	free((void *)config_file);
 	
 	return 0;
 }
@@ -700,7 +756,7 @@ static int event_loop(void)
 			/* Now send the event to the right child */
 			if (conf->p->type == S_SYSLOG) {
 				// Strip out End of event records for syslog
-				if (type != AUDIT_EOE)
+				if (e->hdr.type != AUDIT_EOE)
 					send_syslog(v, e->hdr.ver);
 			} else if (conf->p->type == S_AF_UNIX) {
 				if (conf->p->format == F_STRING)
@@ -880,4 +936,3 @@ static void process_inbound_event(int fd)
 		}
 	}
 }
-
