@@ -234,6 +234,7 @@ static event_list_t *au_get_ready_event(auparse_state_t *au, int is_test)
 {
         int i;
 	au_lol *lol = au->au_lo;
+	au_lolnode *lowest = NULL;
 	
 	if (au->au_ready == 0) {
 		//if (debug) printf("No events ready\n");
@@ -241,23 +242,35 @@ static event_list_t *au_get_ready_event(auparse_state_t *au, int is_test)
 	}
 
         for (i=0; i<=lol->maxi; i++) {
+		// Look for the event with the lowest timestamp
                 au_lolnode *cur = &(lol->array[i]);
-                if (cur->status == EBS_COMPLETE) {
-			/*
-			 * If we are just testing for a complete event, return
-			 */
-			if (is_test)
-				return cur->l;
-			/*
-			 * Otherwise set it status to empty and accept the
-			 * caller will take custody of the memory
-			 */
-                        cur->status = EBS_EMPTY;
-			au->au_ready--;
-                        return cur->l;
-                }
+		if (cur->status == EBS_EMPTY)
+			continue;
+		// If we are just testing for a complete event, return
+		if (is_test && cur->status == EBS_COMPLETE)
+			return cur->l;
+		if (lowest == NULL)
+			lowest = cur;
+		else if (auparse_timestamp_compare(&(lowest->l->e),
+							 &(cur->l->e)) == 1)
+			lowest = cur;
         }
 
+	if (lowest && lowest->status == EBS_COMPLETE) {
+		lowest->status = EBS_EMPTY;
+		au->au_ready--;
+		// Try to consolidate the array so that we iterate
+		// over a smaller portion next time
+		if (lowest == &lol->array[lol->maxi]) {
+			au_lolnode *ptr = lowest;
+			while (ptr->status == EBS_EMPTY && lol->maxi > 0) {
+				lol->maxi--;
+				ptr = &lol->array[lol->maxi];
+			}
+		}
+		return lowest->l;
+	}
+
         return NULL;
 }
 
@@ -283,7 +296,7 @@ static void au_check_events(auparse_state_t *au, time_t sec)
                         if ((r = aup_list_get_cur(cur->l)) == NULL)
 				continue;
                         // If 2 seconds have elapsed, we are done
-                        if (cur->l->e.sec + 2 < sec) {
+                        if (cur->l->e.sec + 2 <= sec) {
                                 cur->status = EBS_COMPLETE;
 				au->au_ready++;
                         } else if ( // FIXME: Check this v remains true
@@ -291,7 +304,9 @@ static void au_check_events(auparse_state_t *au, time_t sec)
 				r->type == AUDIT_EOE || 
 				r->type < AUDIT_FIRST_EVENT ||
 				r->type >= AUDIT_FIRST_ANOM_MSG ||
-				r->type == AUDIT_KERNEL) {
+				r->type == AUDIT_KERNEL ||
+				(r->type >= AUDIT_MAC_UNLBL_ALLOW &&
+                                 r->type <= AUDIT_MAC_CALIPSO_DEL)) {
                                 // If known to be 1 record event, we are done
 				cur->status = EBS_COMPLETE;
 				au->au_ready++;
@@ -521,6 +536,7 @@ auparse_state_t *auparse_init(ausource_t source, const void *b)
 	au->escape_mode = AUPARSE_ESC_TTY;
 	au->message_mode = MSG_QUIET;
 	au->debug_message = DBG_NO;
+	au->tmp_translation = NULL;
 	init_normalizer(&au->norm_data);
 
 	return au;
@@ -667,6 +683,9 @@ int auparse_reset(auparse_state_t *au)
 		au_lol_clear(au->au_lo, 1);
 
 	au->parse_state = EVENT_EMPTY;
+	au->au_ready = 0;
+	au->le = NULL;
+
 	switch (au->source)
 	{
 		case AUSOURCE_LOGS:
@@ -723,6 +742,7 @@ static int add_expr(auparse_state_t *au, struct expr *expr, ausearch_rule_t how)
 		}
 		au->expr = e;
 	}
+	au->expr->started = 0;
 	return 0;
 }
 
@@ -931,6 +951,7 @@ static void auparse_destroy_common(auparse_state_t *au)
 	free_interpretation_list();
 	clear_normalizer(&au->norm_data);
 	au_lol_clear(au->au_lo, 0);
+	free((void *)au->tmp_translation);
 	free(au->au_lo);
 	free(au);
 }
@@ -1073,25 +1094,27 @@ static int str2event(char *s, au_event_t *e)
 	char *ptr;
 
 	errno = 0;
-	ptr = strchr(s+10, ':');
+	e->sec = strtoul(s, NULL, 10);
+	if (errno)
+		return -1;
+	ptr = strchr(s, '.');
 	if (ptr) {
-		e->serial = strtoul(ptr+1, NULL, 10);
-		*ptr = 0;
+		ptr++;
+		e->milli = strtoul(ptr, NULL, 10);
+		if (errno)
+			return -1;
+		s = ptr;
+	} else
+		e->milli = 0;
+	
+	ptr = strchr(s, ':');
+	if (ptr) {
+		ptr++;
+		e->serial = strtoul(ptr, NULL, 10);
 		if (errno)
 			return -1;
 	} else
 		e->serial = 0;
-	ptr = strchr(s, '.');
-	if (ptr) {
-		e->milli = strtoul(ptr+1, NULL, 10);
-		*ptr = 0;
-		if (errno)
-			return -1;
-	} else
-		e->milli = 0;
-	e->sec = strtoul(s, NULL, 10);
-	if (errno)
-		return -1;
 	return 0;
 }
 
@@ -1136,7 +1159,7 @@ static int extract_timestamp(const char *b, au_event_t *e)
 		// else we have a bad line
 	}
 	if (rc)
-		free(e->host);
+		free((void *)e->host);
 
 	// else we have a bad line
 	return rc;
@@ -1301,8 +1324,10 @@ static int ausearch_compare(auparse_state_t *au)
 		return 0;
 
 	r = aup_list_get_cur(au->le);
-	if (r)
-		return expr_eval(au, r, au->expr);
+	if (r) {
+		int res = expr_eval(au, r, au->expr);
+		return res;
+	}
 
 	return 0;
 }
@@ -1316,8 +1341,14 @@ int ausearch_next_event(auparse_state_t *au)
 		errno = EINVAL;
 		return -1;
 	}
-	if ((rc = auparse_first_record(au)) <= 0)
-		return rc;
+	if (au->expr->started == 0) {
+		if ((rc = auparse_first_record(au)) <= 0)
+			return rc;
+		au->expr->started = 1;
+	} else {
+		if ((rc = auparse_next_event(au)) <= 0)
+			return rc;
+	}
         do {
 		do {
 			if ((rc = ausearch_compare(au)) > 0) {
@@ -1701,6 +1732,7 @@ int auparse_goto_record_num(auparse_state_t *au, unsigned int num)
 	r = aup_list_goto_rec(au->le, num);
 	if (r != NULL) {
 		load_interpretation_list(r->interp);
+		aup_list_first_field(au->le);
 		return 1;
 	} else
 		return 0;
@@ -2012,3 +2044,61 @@ const char *auparse_interpret_realpath(auparse_state_t *au)
 	return NULL;
 }
 
+static const char *auparse_interpret_sock_parts(auparse_state_t *au,
+	const char *field)
+{
+	if (au->le == NULL)
+		return NULL;
+
+        if (au->le->e.sec) {
+        	rnode *r = aup_list_get_cur(au->le);
+		if (r == NULL)
+			return NULL;
+		// This is limited to socket address fields
+		if (nvlist_get_cur_type(r) != AUPARSE_TYPE_SOCKADDR)
+			return NULL;
+		// Get interpretation
+		const char *val = nvlist_interp_cur_val(r, au->escape_mode);
+		if (val == NULL)
+			return NULL;
+		// make a copy since we modify it
+		char *tmp = strdup(val);
+		if (tmp == NULL)
+			return NULL;
+		// Locate the address part
+		val = strstr(tmp, field);
+		if (val) {
+			// Get past the =
+			val += strlen(field);
+			// find other side
+			char *ptr = strchr(val, ' ');
+			if (ptr) {
+				// terminate, copy, and return it
+				*ptr = 0;
+				const char *final = strdup(val);
+				free(tmp);
+				free((void *)au->tmp_translation);
+				au->tmp_translation = final;
+				return final;
+			}
+		}
+		free(tmp);
+        }
+	return NULL;
+}
+
+const char *auparse_interpret_sock_family(auparse_state_t *au)
+{
+	return auparse_interpret_sock_parts(au, "fam=");
+}
+
+const char *auparse_interpret_sock_port(auparse_state_t *au)
+{
+	return auparse_interpret_sock_parts(au, "lport=");
+}
+
+const char *auparse_interpret_sock_address(auparse_state_t *au)
+{
+	return auparse_interpret_sock_parts(au, "laddr=");
+}
+
