@@ -1,5 +1,5 @@
 /* sockoptnametab.h --
- * Copyright 2013-15 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2013-16 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -72,6 +72,16 @@ _S(47, "SO_MAX_PACING_RATE")
 _S(48, "SO_BPF_EXTENSIONS")
 _S(49, "SO_INCOMING_CPU")
 _S(50, "SO_ATTACH_BPF")
+_S(51, "SO_ATTACH_REUSEPORT_CBPF")
+_S(52, "SO_ATTACH_REUSEPORT_EBPF")
+_S(53, "SO_CNX_ADVICE")
+_S(54, "SCM_TIMESTAMPING_OPT_STATS")
+_S(55, "SO_MEMINFO")
+_S(56, "SO_INCOMING_NAPI_ID")
+_S(57, "SO_COOKIE")
+_S(58, "SCM_TIMESTAMPING_PKTINFO")
+_S(59, "SO_PEERGROUPS")
+_S(60, "SO_ZEROCOPY")
 
 // PPC has these different
 _S(116, "SO_RCVLOWAT")
