@@ -62,7 +62,7 @@ struct auditd_remote_message_wrapper {
 /* If set, this reply indicates success but with some warnings.  */
 #define AUDIT_RMW_TYPE_WARNMASK		0x10000000
 /* This part of the message type is the details for the above.  */
-#define AUDIT_RMW_TYPE_DETAILMASK	0x0fffffff
+#define AUDIT_RMW_TYPE_DETAILMASK	0x000FFFFF
 
 /* Version 0 messages.  */
 #define AUDIT_RMW_TYPE_MESSAGE		0x00000000
@@ -121,6 +121,7 @@ void audit_msg(int priority, const char *fmt, ...)
 #endif
 
 extern int audit_send(int fd, int type, const void *data, unsigned int size);
+extern int __audit_send(int fd, int type, const void *data, unsigned int size, int *seq);
 
 AUDIT_HIDDEN_START
 
@@ -139,6 +140,7 @@ extern int _audit_permadded;
 extern int _audit_archadded;
 extern int _audit_syscalladded;
 extern int _audit_exeadded;
+extern int _audit_filterfsadded;
 extern unsigned int _audit_elf;
 
 #ifdef __cplusplus
