@@ -353,3 +353,5 @@ _S(329, "pkey_mprotect")
 _S(330, "pkey_alloc")
 _S(331, "pkey_free")
 _S(332, "statx")
+_S(333, "io_pgetevents")
+_S(334, "rseq")
