@@ -15,7 +15,8 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING. If not, write to the
-* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor 
+* Boston, MA 02110-1335, USA.
 *
 * Authors:
 *   Steve Grubb <sgrubb@redhat.com>
@@ -580,13 +581,13 @@ void print_per_event_item(llist *l)
 			slist *s = l->s.filename;
 			slist_first(s);
 			if (s->cnt > 1) {
-				char *key = s->cur->key;
+				char *key = s->cur ? s->cur->key : NULL;
 				while (key && strcmp(key, "PARENT") == 0) {
 					slist_next(s);
-					key = s->cur->key;
+					key = s->cur ? s->cur->key : NULL;
 				}
 			}
-			safe_print_string(s->cur->str,0);
+			safe_print_string(s->cur ? s->cur->str : "", 0);
 			printf(" %s %s ",
 				aulookup_syscall(l,buf,sizeof(buf)),
 				aulookup_success(l->s.success));
