@@ -15,7 +15,8 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING. If not, write to the
-* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor 
+* Boston, MA 02110-1335, USA.
 *
 * Authors:
 *   Steve Grubb <sgrubb@redhat.com>
@@ -404,7 +405,7 @@ static void interpret(char *name, char *val, int comma, int rtype)
 /* This function will output a normalized line of audit
  * fields one line per event in csv format */
 static int csv_header_done = 0;
-extern int extra_keys, extra_labels, extra_time;
+extern int extra_keys, extra_labels, extra_obj2, extra_time;
 static void csv_event(auparse_state_t *au,
 		auparse_cb_event_t cb_event_type, void *user_data)
 {
@@ -415,9 +416,10 @@ static void csv_event(auparse_state_t *au,
 		csv_header_done = 1;
 		printf( "NODE,EVENT,DATE,TIME,%sSERIAL_NUM,EVENT_KIND,"
 			"SESSION,SUBJ_PRIME,SUBJ_SEC,SUBJ_KIND,%sACTION,"
-			"RESULT,OBJ_PRIME,OBJ_SEC,%sOBJ_KIND,HOW%s\n",
+			"RESULT,OBJ_PRIME,OBJ_SEC,%s%sOBJ_KIND,HOW%s\n",
 		    extra_time ? "YEAR,MONTH,DAY,WEEKDAY,HOUR,GMT_OFFSET," : "",
 			extra_labels ? "SUBJ_LABEL," : "",
+			extra_obj2 ? "OBJ2," : "",
 			extra_labels ? "OBJ_LABEL," : "",
 			extra_keys ? ",KEY" : "");
 	}
@@ -432,7 +434,7 @@ static void csv_event(auparse_state_t *au,
 	item = auparse_get_node(au);
 	if (item) {
 		printf("%s", auparse_interpret_field(au));
-		free(item);
+		free((void *)item);
 	}
 	putchar(',');
 
@@ -581,6 +583,9 @@ static void csv_event(auparse_state_t *au,
 			i = 1;
 		else if (strncmp(item, "suc", 3) == 0)
 			i = 1;
+		else if (auparse_get_field_type(au) == AUPARSE_TYPE_SECCOMP &&
+				strcmp(item, "allow") == 0)
+			i = 1;
 		printf("%s", res[i]);
 	}
 	putchar(',');
@@ -604,6 +609,22 @@ static void csv_event(auparse_state_t *au,
 		printf("%s", auparse_interpret_field(au));
 	putchar(',');
 
+	// OBJECT 2
+	if (extra_obj2) {
+		rc = auparse_normalize_object_primary2(au);
+		if (rc == 1) {
+			const char *val;
+
+			if (auparse_get_field_type(au) ==
+						AUPARSE_TYPE_ESCAPED_FILE)
+				val = auparse_interpret_realpath(au);
+			else
+				val = auparse_interpret_field(au);
+			printf("%s", val);
+		}
+		putchar(',');
+	}
+
 	// OBJ_LABEL
 	if (extra_labels) {
 		rc = auparse_normalize_object_first_attribute(au);
@@ -663,7 +684,7 @@ static void text_event(auparse_state_t *au,
 	item = auparse_get_node(au);
 	if (item) {
 		printf("On %s at %s ", auparse_interpret_field(au), tmp);
-		free(item);
+		free((void *)item);
 	} else
 		printf("At %s ", tmp);
 
@@ -693,6 +714,9 @@ static void text_event(auparse_state_t *au,
 			i = 1;
 		else if (strncmp(item, "suc", 3) == 0)
 			i = 1;
+		else if (auparse_get_field_type(au) == AUPARSE_TYPE_SECCOMP &&
+				strcmp(item, "allow") == 0)
+			i = 1;
 		printf(" %s ", res[i]);
 	} else
 		putchar(' ');
@@ -707,24 +731,37 @@ static void text_event(auparse_state_t *au,
 
 	rc = auparse_normalize_object_primary(au);
 	if (rc == 1) {
-		const char *val;
+		const char *val = NULL;
+		int ftype;
 
 		// If we have an object and this is an AVC, add some words
 		if (action && strstr(action, "violated"))
-			printf("accessing ");
+			val = "accessing ";
+
+		ftype = auparse_get_field_type(au);
+		if (ftype == AUPARSE_TYPE_ESCAPED_FILE)
+			val = auparse_interpret_realpath(au);
+		else if (ftype == AUPARSE_TYPE_SOCKADDR) {
+			val = auparse_interpret_sock_address(au);
+			if (val == NULL)
+				val = auparse_interpret_sock_family(au);
+		}
+
+		if (val == NULL)
+			val = auparse_interpret_field(au);
+
+		printf("%s ", val);
+	}
+
+	rc = auparse_normalize_object_primary2(au);
+	if (rc == 1) {
+		const char *val;
 
 		if (auparse_get_field_type(au) == AUPARSE_TYPE_ESCAPED_FILE)
 			val = auparse_interpret_realpath(au);
 		else
 			val = auparse_interpret_field(au);
-		printf("%s ", val);
-	}
-
-	if (    type == AUDIT_VIRT_RESOURCE ||
-		type == AUDIT_VIRT_CONTROL) {
-		rc = auparse_normalize_object_secondary(au);
-		if (rc)
-			printf("to %s ", auparse_interpret_field(au));
+		printf("to %s ", val);
 	}
 
 	how = auparse_normalize_how(au);
